==> dwarfg_install_1.2.0.tgz: dwarfg_install/appdir/upgrade_from_1.1.0.sh <==
#!/bin/bash

# upgrade script from 1.1.0 to 1.2.0
SNAME="U_110_120"
STXT="   ---> $SNAME <---   "
DB_MIGRATE_SCRIPT="db_migrate_110_to_120.sql"
echo "Upgrade script $SNAME starting up..."

[ $# -eq 1 ] || {
	echo "Need a path to existing Dwarfguard deployment." >&2
	exit 1
}

BASEDEFS="base_defs"
FUNCS="deploy_funcs.sh"
MYSQOPT=${MYSQOPT:-}
[ -n "$MYSQL_PWD" ] && MYSQOPT="$MYSQOPT -p$MYSQL_PWD"
export MYSQOPT
# get old directory from 1st parameter
DWARFG_OLD_DIR="$1"

# get new directory from $0
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"

g_tardef="$DIR/$BASEDEFS"
[[ -f "$DWARFG_OLD_DIR/base_defs" && -f "$g_tardef" ]] || {
	echo "Either $DWARFG_OLD_DIR/base_defs or $DIR/$BASEDEFS are missing." >&2
	exit 1
}

# pick the old definitions first...
. "$DWARFG_OLD_DIR/base_defs" || {
	echo "Unable to source old definitions file ($DWARFG_OLD_DIR/base_defs)" >&2
	exit 1
}

[ -n "$DWARFG_HOME" ] || {
	echo "Dwarfguard home variable (DWARFG_HOME) is empty. Possibly corrupted base definitions file. Restore from backup or perform manual recovery steps." >&2
	exit 1
}

g_upg_log="$DWARFG_HOME/upgrade_log.txt"
echo "$STXT Creating upgrade log $g_upg_log"

# create upgrade log in dwarfg home
echo -e "\n$STST $(date -Iseconds) Executing upgrade using $0" >>$g_upg_log

[ -f "$DIR/$DB_MIGRATE_SCRIPT" ] || {
	echo "Unable to find DB migration script" | tee -a $g_upg_log >&2
	exit 1
}

UPGRADING=1
export UPGRADING

mysql $MYSQOPT <<EOF
exit
EOF
[ $? -eq 0 ] || {
	echo "Unable to run mysql under root. You can specify your password in the MYSQL_PWD enviroment variable" | tee -a $g_upg_log >&2
	exit 1
}

# update new definitions
echo "$STXT updating definitions in $g_tardef" | tee -a $g_upg_log
sed -i --follow-symlinks "s#^\(DOMAIN\)=.*#\1=\"$DOMAIN\"#" $g_tardef
sed -i --follow-symlinks "s#^\(EXTERNURL\)=.*#\1=\"$EXTERNURL\"#" $g_tardef
sed -i --follow-symlinks "s#^\(SERVID\)=.*#\1=\"$SERVID\"#" $g_tardef
sed -i --follow-symlinks "s#^\(PORT_OFFSET\)=.*#\1=\"$PORT_OFFSET\"#" $g_tardef
sed -i --follow-symlinks "s#^\(SERV_TUNSSH_PORT\)=.*#\1=\"$SERV_TUNSSH_PORT\"#" $g_tardef
sed -i --follow-symlinks "s#^\(USE_SSL\)=.*#\1=\"$USE_SSL\"#" $g_tardef
sed -i --follow-symlinks "s#^\(DWARFG_PORT\)=.*#\1=\"$DWARFG_PORT\"#" $g_tardef
sed -i --follow-symlinks "s#^\(WEBSSH_PORT\)=.*#\1=\"$WEBSSH_PORT\"#" $g_tardef
sed -i --follow-symlinks "s#^\(BASEDIR\)=.*#\1=\"$BASEDIR\"#" $g_tardef
sed -i --follow-symlinks "s#^\(SYSCTLPATH\)=.*#\1=\"$SYSCTLPATH\"#" $g_tardef
sed -i --follow-symlinks "s#^\(AGENT_FORCED_SECURITY\)=.*#\1=\"$AGENT_FORCED_SECURITY\"#" $g_tardef
cp -r $DWARFG_OLD_DIR/dwarfg_license.lic $DWARFG_OLD_DIR/myCA* $DWARFG_OLD_DIR/server.* $DWARFG_OLD_DIR/ssl $DIR/ 2>/dev/null

# run cleanup
echo "$STXT calling cleanup (upgrade mode) $DWARFG_OLD_DIR/cleanup.sh" | tee -a $g_upg_log
"$DWARFG_OLD_DIR/cleanup.sh" --upgrade --yes || {
	echo "Error when running $DWARFG_OLD_DIR/cleanup.sh, trying to continue with upgrade anyway." | tee -a $g_upg_log >&2
}

# switch to new env
echo "$STXT switching to new env ($g_tardef)" | tee -a $g_upg_log
. "$g_tardef" || {
	echo "Unable to source new definitions file ($g_tardef)" | tee -a $g_upg_log >&2
	exit 1
}
. "$DIR/$FUNCS" || {
	echo "Unable to source new function file ($DIR/$FUNCS)" | tee -a $g_upg_log >&2
	exit 1
}
read_defs || {
	echo "Unable to perform read_defs()." | tee -a $g_upg_log >&2
	exit 1
}
validate_deploy_commands || {
	echo "Failed to validate deploy commands" | tee -a $g_upg_log >&2
	exit 1
}

# recreate directories
echo "$STXT recreating $BINDIR, $SRVDIR..." | tee -a $g_upg_log
mkdir -p $BINDIR $SRVDIR
chown $APPUSER $BINDIR
touch "$BINDIR/upgrading"

# migrate DB data
echo "$STXT calling DB migration script..." | tee -a $g_upg_log
mysql $MYSQOPT "$DWARFG_DBN" <"$DIR/$DB_MIGRATE_SCRIPT"
[ $? -ne 0 ] && {
	echo "Failed to migrate DB." | tee -a $g_upg_log >&2
	exit 1
}

# deploy (using upgrading mode)
echo "$STXT Executing $DIR/deploy.sh $PARAM_UPGRADE $PARAM_FORCE ... (DOM/EURL is $DOMAIN/$EXTERNURL)" | tee -a $g_upg_log
$DIR/deploy.sh $PARAM_UPGRADE $PARAM_FORCE

# start service
echo "$STXT Starting Dwarfguard service: ${DWARFG_NAM}..." | tee -a $g_upg_log
systemctl start ${DWARFG_NAM}.service || {
	echo "Unable to start Dwarfguard service after upgrade" | tee -a $g_upg_log >&2
	exit 1
}

echo -e "$SNAME: $(date -Iseconds) Upgrade by $0 finished\n" | tee -a $g_upg_log
event_log 309

==> dwarfg_install_1.3.0.tgz: dwarfg_install/appdir/upgrade_from_1.2.0.sh <==
#!/bin/bash

# upgrade script from 1.2.0 to 1.3.0
SNAME="U_120_130"
STXT="   ---> $SNAME <---   "
DB_MIGRATE_SCRIPT="db_migrate_120_to_130.sql"
echo "Upgrade script $SNAME starting up..."

[ $# -eq 1 ] || {
	echo "Need a path to existing Dwarfguard deployment." >&2
	exit 1
}

BASEDEFS="base_defs"
FUNCS="deploy_funcs.sh"
MYSQOPT=${MYSQOPT:-}
[ -n "$MYSQL_PWD" ] && MYSQOPT="$MYSQOPT -p$MYSQL_PWD"
export MYSQOPT
# get old directory from 1st parameter
DWARFG_OLD_DIR="$1"

# get new directory from $0
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"

g_tardef="$DIR/$BASEDEFS"
[[ -f "$DWARFG_OLD_DIR/base_defs" && -f "$g_tardef" ]] || {
	echo "Either $DWARFG_OLD_DIR/base_defs or $DIR/$BASEDEFS are missing." >&2
	exit 1
}

# pick the old definitions first...
. "$DWARFG_OLD_DIR/base_defs" || {
	echo "Unable to source old definitions file ($DWARFG_OLD_DIR/base_defs)" >&2
	exit 1
}

# grab Python EXT and Grafana integration status from GUI defs
[ -f "$DWARFG_OLD_DIR/web/gui/.env" ] && {
	source <(grep "DWARFG_UI_GRAFANA_REDIR=" "$DWARFG_OLD_DIR/web/gui/.env")
	source <(grep "DWARFG_UI_PYEXT_AVAIL=" "$DWARFG_OLD_DIR/web/gui/.env")
}

$(grep "$varname=" "$file" | sed "s/.*=//")

[ -n "$DWARFG_HOME" ] || {
	echo "Dwarfguard home variable (DWARFG_HOME) is empty. Possibly corrupted base definitions file. Restore from backup or perform manual recovery steps." >&2
	exit 1
}

g_upg_log="$DWARFG_HOME/upgrade_log.txt"
echo "$STXT Creating upgrade log $g_upg_log"

# create upgrade log in dwarfg home
echo -e "\n$STST $(date -Iseconds) Executing upgrade using $0" >>$g_upg_log

[ -f "$DIR/$DB_MIGRATE_SCRIPT" ] || {
	echo "Unable to find DB migration script" | tee -a $g_upg_log >&2
	exit 1
}

UPGRADING=1
export UPGRADING

mysql $MYSQOPT <<EOF
exit
EOF
[ $? -eq 0 ] || {
	echo "Unable to run mysql under root. You can specify your password in the MYSQL_PWD enviroment variable" | tee -a $g_upg_log >&2
	exit 1
}

# update new definitions
echo "$STXT updating definitions in $g_tardef" | tee -a $g_upg_log
sed -i --follow-symlinks "s#^\(DOMAIN\)=.*#\1=\"$DOMAIN\"#" $g_tardef
sed -i --follow-symlinks "s#^\(EXTERNURL\)=.*#\1=\"$EXTERNURL\"#" $g_tardef
sed -i --follow-symlinks "s#^\(SERVID\)=.*#\1=\"$SERVID\"#" $g_tardef
sed -i --follow-symlinks "s#^\(PORT_OFFSET\)=.*#\1=\"$PORT_OFFSET\"#" $g_tardef
sed -i --follow-symlinks "s#^\(SERV_TUNSSH_PORT\)=.*#\1=\"$SERV_TUNSSH_PORT\"#" $g_tardef
sed -i --follow-symlinks "s#^\(USE_SSL\)=.*#\1=\"$USE_SSL\"#" $g_tardef
sed -i --follow-symlinks "s#^\(DWARFG_PORT\)=.*#\1=\"$DWARFG_PORT\"#" $g_tardef
sed -i --follow-symlinks "s#^\(WEBSSH_PORT\)=.*#\1=\"$WEBSSH_PORT\"#" $g_tardef
sed -i --follow-symlinks "s#^\(BASEDIR\)=.*#\1=\"$BASEDIR\"#" $g_tardef
sed -i --follow-symlinks "s#^\(SYSCTLPATH\)=.*#\1=\"$SYSCTLPATH\"#" $g_tardef
sed -i --follow-symlinks "s#^\(AGENT_FORCED_SECURITY\)=.*#\1=\"$AGENT_FORCED_SECURITY\"#" $g_tardef
cp -r $DWARFG_OLD_DIR/dwarfg_license.lic $DWARFG_OLD_DIR/myCA* $DWARFG_OLD_DIR/server.* $DWARFG_OLD_DIR/ssl $DIR/ 2>/dev/null

# run cleanup
echo "$STXT calling cleanup (upgrade mode) $DWARFG_OLD_DIR/cleanup.sh" | tee -a $g_upg_log
"$DWARFG_OLD_DIR/cleanup.sh" --upgrade --yes || {
	echo "Error when running $DWARFG_OLD_DIR/cleanup.sh, trying to continue with upgrade anyway." | tee -a $g_upg_log >&2
}

# switch to new env
echo "$STXT switching to new env ($g_tardef)" | tee -a $g_upg_log
. "$g_tardef" || {
	echo "Unable to source new definitions file ($g_tardef)" | tee -a $g_upg_log >&2
	exit 1
}
. "$DIR/$FUNCS" || {
	echo "Unable to source new function file ($DIR/$FUNCS)" | tee -a $g_upg_log >&2
	exit 1
}
read_defs || {
	echo "Unable to perform read_defs()." | tee -a $g_upg_log >&2
	exit 1
}
validate_deploy_commands || {
	echo "Failed to validate deploy commands" | tee -a $g_upg_log >&2
	exit 1
}

# recreate directories
echo "$STXT recreating $BINDIR, $SRVDIR..." | tee -a $g_upg_log
mkdir -p $BINDIR $SRVDIR
chown $APPUSER $BINDIR
touch "$BINDIR/upgrading"

# migrate DB data
echo "$STXT calling DB migration script..." | tee -a $g_upg_log
mysql $MYSQOPT "$DWARFG_DBN" <"$DIR/$DB_MIGRATE_SCRIPT"
[ $? -ne 0 ] && {
	echo "Failed to migrate DB." | tee -a $g_upg_log >&2
	exit 1
}

# deploy (using upgrading mode)
echo "$STXT Executing $DIR/deploy.sh $PARAM_UPGRADE $PARAM_FORCE ... (DOM/EURL is $DOMAIN/$EXTERNURL)" | tee -a $g_upg_log
$DIR/deploy.sh $PARAM_UPGRADE $PARAM_FORCE

# start service
echo "$STXT Starting Dwarfguard service: ${DWARFG_NAM}..." | tee -a $g_upg_log
systemctl start ${DWARFG_NAM}.service || {
	echo "Unable to start Dwarfguard service after upgrade" | tee -a $g_upg_log >&2
	exit 1
}

[ -n "$DWARFG_UI_GRAFANA_REDIR" ] && echo -e "\n\t=== WARNING ===\n\t\tYou need to perform dwarfg_grafint to re-enable Grafana integration.\n";
[ -n "$DWARFG_UI_PYEXT_AVAIL=" ] && echo -e "\n\t=== WARNING ===\n\t\tYou need to perform dwarfg_inst_pyext to re-enable Python libs and SNMP Gateway.\n";

echo -e "$SNAME: $(date -Iseconds) Upgrade by $0 finished\n" | tee -a $g_upg_log
event_log 309
